@@ -1,6 +1,7 @@
 from enum import Enum
 from ipaddress import IPv4Address
 from typing import TypeVar, List, Any, Dict
+from uuid import UUID
 
 from tortoise import fields
 from tortoise.fields import ReverseRelation
@@ -26,6 +27,8 @@ class AbstractDbModel(Model):
             if _field_in_drop(k):
                 continue
             v = string_from_db_date(v, iso_date_format)
+            if isinstance(v, UUID):
+                v = str(v)
             if isinstance(v, IPv4Address):
                 v = str(v)
             if isinstance(v, Enum):
