@@ -15,6 +15,9 @@ class RouteMethodConf:
     in_dto: Type[BaseModel] | None
     out_dto: Type[BaseModel] | None
     handler: HandlerType
+    chain: HandlerType
+    version_prefix: str | None
+    version: str | None
 
 
 @dataclass
